@@ -10,7 +10,8 @@ def main() -> None:
     files = sys.argv[1:]
     parser = Parser(TokenFormatterBuilder())
     for file in files:
-        scanner = TokenScanner(file)
+        source = open(file, encoding="utf8", newline="").read()  # noqa: PTH123
+        scanner = TokenScanner(source)
 
         if file.endswith(".md"):
             print(parser.parse(scanner, GherkinInMarkdownTokenMatcher()))
